pub enum Role {
System,
User,
Assistant,
Tool,
}Variants
Implementations
Sourceimpl Role
impl Role
Sourcepub const fn as_wire_str(self) -> &'static str
pub const fn as_wire_str(self) -> &'static str
Canonical wire string. Single source of truth for any code path that talks to an LLM HTTP API or persists messages.
Sourcepub fn from_wire_str(s: &str) -> Option<Self>
pub fn from_wire_str(s: &str) -> Option<Self>
Parse the canonical wire string back into a Role. Returns
None for unknown values — callers must decide whether to error
or default; we deliberately do NOT silently coerce.