pub trait Sandbox: Send + Sync {
// Required methods
fn availability(&self) -> &'static str;
fn enforces(&self) -> bool;
}Expand description
Sandbox boundary: wrap an MCP server child process so that any tool invocation can only access an explicitly granted set of paths and syscalls.
Required Methods
Sourcefn availability(&self) -> &'static str
fn availability(&self) -> &'static str
Returns a tag like "seccomp+landlock", "unsupported(macos)".